@@ -1,21 +1,8 @@
 /* This file is part of the KDE project
-   Copyright (C) 1998, 1999 Torben Weis <weis@kde.org>
-   Copyright (C) 2006 Daniel Teske <teske@squorn.de>
+    SPDX-FileCopyrightText: 1998, 1999 Torben Weis <weis@kde.org>
+    SPDX-FileCopyrightText: 2006 Daniel Teske <teske@squorn.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "konqbookmarkmenu.h"
@@ -262,11 +249,11 @@ QAction *KonqBookmarkMenu::actionForBookmark(const KBookmark &_bm)
     } else {
         // qCDebug(KBOOKMARKS_LOG) << "Creating Konq bookmark action named " << bm.text();
         QUrl host = bm.url().adjusted(QUrl::RemovePath | QUrl::RemoveQuery);
-        bm.setIcon(KonqPixmapProvider::self()->iconNameFor(host));
+            bm.setIcon(KonqPixmapProvider::self()->iconNameFor(host));
         KBookmarkAction *action = new KBookmarkAction(bm, owner(), this);
-        connect(KonqPixmapProvider::self(), &KonqPixmapProvider::changed, action, [host, action]() {
-            action->setIcon(KonqPixmapProvider::self()->iconForUrl(host));
-        });
+            connect(KonqPixmapProvider::self(), &KonqPixmapProvider::changed, action, [host, action]() {
+                action->setIcon(KonqPixmapProvider::self()->iconForUrl(host));
+            });
         KonqPixmapProvider::self()->downloadHostIcon(host);
         m_actionCollection->addAction(action->objectName(), action);
         m_actions.append(action);
